@@ -68,6 +68,11 @@ def get_cmd_pairs(locations, remote_schema=None, ssh_compression=True,
         if Globals.get_api_version() > 200:  # compat200
             cmd_schema += b" server"
         else:
+            log.Log("Server will be called with deprecated command line "
+                    "interface to guarantee compatibility. It might lead to "
+                    "a deprecation warning from newer rdiff-backup versions. "
+                    "Use '--api-version 201' (or higher) to avoid it.",
+                    log.WARNING)
             cmd_schema += b" --server"
 
     if not locations:
@@ -490,8 +495,12 @@ def _test_connection(conn_number, rp):
     # FIXME the tests don't sound right, the path given needs to pre-exist
     # on Windows but not on Linux? What are we exactly testing here?
     try:
-        assert conn.Globals.get('current_time') is None
-        assert type(conn.os.listdir(rp.path)) is list
+        remote_time = conn.Globals.get('current_time')
+        assert remote_time == Globals.current_time, (
+            "connection not returning current time {ct1} but {ct2}".format(
+                ct1=Globals.current_time, ct2=remote_time))
+        assert type(conn.os.listdir(rp.path)) is list, (
+            "connection not listing directory '{rp}'".format(rp=rp))
     except BaseException as exc:
         sys.stderr.write("- Server tests failed due to {exc}\n".format(exc=exc))
         return False
